==> v5.1.1.tar.gz: barker/bookie/src/app/devices/device-detail/device-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { Device } from '../../core/device';
import { Section } from '../../core/section';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { DeviceService } from '../device.service';

@Component({
  selector: 'app-device-detail',
  templateUrl: './device-detail.component.html',
  styleUrls: ['./device-detail.component.css'],
})
export class DeviceDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup;
  sections: Section[] = [];
  item: Device = new Device();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: DeviceService,
  ) {
    // Create form
    this.form = this.fb.group({
      name: '',
      section: '',
      enabled: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Device; sections: Section[] };
      this.showItem(data.item);
      this.sections = data.sections;
    });
  }

  showItem(item: Device) {
    this.item = item;
    this.form.setValue({
      name: this.item.name || '',
      section: this.item.section.id ? this.item.section.id : '',
      enabled: this.item.enabled,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/devices');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/devices');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Device?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Device {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    this.item.section.id = formModel.section;
    this.item.enabled = formModel.enabled;
    return this.item;
  }
}

==> v11.2.0.tar.gz: barker/bookie/src/app/devices/device-detail/device-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { Device } from '../../core/device';
import { Section } from '../../core/section';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { DeviceService } from '../device.service';

@Component({
  selector: 'app-device-detail',
  templateUrl: './device-detail.component.html',
  styleUrls: ['./device-detail.component.css'],
})
export class DeviceDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('nameElement', { static: true }) nameElement?: ElementRef;
  form: FormGroup<{
    name: FormControl<string>;
    section: FormControl<string | null>;
    enabled: FormControl<boolean>;
  }>;

  sections: Section[] = [];
  item: Device = new Device();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private toaster: ToasterService,
    private ser: DeviceService,
  ) {
    // Create form
    this.form = new FormGroup({
      name: new FormControl<string>('', { nonNullable: true }),
      section: new FormControl<string | null>(null),
      enabled: new FormControl<boolean>(false, { nonNullable: true }),
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Device; sections: Section[] };
      this.showItem(data.item);
      this.sections = data.sections;
    });
  }

  showItem(item: Device) {
    this.item = item;
    this.form.setValue({
      name: this.item.name ?? '',
      section: this.item.section.id ? this.item.section.id : '',
      enabled: this.item.enabled,
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/devices');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/devices');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Device?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Device {
    const formModel = this.form.value;
    this.item.name = formModel.name ?? '';
    this.item.section.id = formModel.section ?? '';
    this.item.enabled = formModel.enabled ?? true;
    return this.item;
  }
}
